Concordance for joint models
ConcordanceJMMLSM(
seed = 100,
object,
opt = "nlminb",
n.cv = 3,
maxiter = 10000,
initial.optimizer = "BFGS",
initial.para = TRUE,
...
)a list of matrices with conditional probabilities for subjects.
a numeric value of seed to be specified for cross validation.
object of class 'JMMLSM'.
Optimization method to fit a linear mixed effects model, either nlminb (default) or optim.
number of folds for cross validation. Default is 3.
the maximum number of iterations of the EM algorithm that the function will perform. Default is 10000.
Method for numerical optimization to be used. Default is BFGS.
Initial guess of parameters for cross validation. Default is FALSE.
Further arguments passed to or from other methods.
Shanpeng Li lishanpeng0913@ucla.edu
JMMLSM