Learn R Programming

JMH (version 1.0.4)

summary: Summaries of evaluation metrics for joint models

Description

Produce result summaries of a joint model fit.

Usage

# S3 method for AUCJMMLSM
summary(object, digits = 4, ...)

# S3 method for ConcordanceJMMLSM summary(object, digits = 4, ...)

# S3 method for JMMLSM summary(object, process = c("longitudinal", "survival"), digits = 4, ...)

# S3 method for MAEQJMMLSM summary(object, digits = 3, ...)

# S3 method for PEJMMLSM summary(object, error = c("MAE", "Brier"), ...)

Value

a list of matrices with conditional probabilities for subjects.

a list of matrices with conditional probabilities for subjects.

A table to summarize the model results.

a list of matrices with conditional probabilities for subjects.

a list of matrices with conditional probabilities for subjects.

Arguments

object

object of class 'PEJMMLSM'.

digits

number of decimal points to be rounded.

...

Further arguments passed to or from other methods.

process

for which model (i.e., longitudinal model or survival model) to extract the estimated coefficients.

error

a character string that specifies the loss function.

Author

Shanpeng Li lishanpeng0913@ucla.edu

See Also

JMMLSM, survfitJMMLSM

JMMLSM, survfitJMMLSM

JMMLSM

JMMLSM, survfitJMMLSM

JMMLSM, survfitJMMLSM